@@ -1,19 +1,30 @@
 
 package Module::Spec;
-$Module::Spec::VERSION = '0.4.0';
+$Module::Spec::VERSION = '0.5.0';
 # ABSTRACT: Load modules based on specifications
 use 5.010;
 
 # use strict;
 # use warnings;
 
-use Module::Spec::V1 ();
+BEGIN {
+    require Module::Spec::V1;
+    *croak = \&Module::Spec::V1::croak;
+}
 
 sub new {
     my ( $self, %args ) = @_;
-    Module::Spec::V1::croak qq{What version?} unless my $v = $args{ver};
-    Module::Spec::V1::_require_module( my $m = "Module::Spec::V$v" );
-    return bless {}, $m;
+
+    croak qq{What version?} unless exists $args{ver};
+
+    my $v = $args{ver};
+    unless ( defined $v && $v =~ /\A[0-9]+\z/ ) {
+        croak qq{Invalid version ($v)} if defined $v;
+        croak qq{Undefined version};
+    }
+
+    require Module::Spec::OO;
+    return bless {}, Module::Spec::OO->create_class($v);
 }
 
 1;
@@ -41,7 +52,7 @@ Module::Spec - Load modules based on specifications
 
 =head1 VERSION
 
-version 0.4.0
+version 0.5.0
 
 =head1 SYNOPSIS
 
