@@ -1,14 +1,12 @@
 
 package Module::Spec::V1;
-$Module::Spec::V1::VERSION = '0.4.0';
+$Module::Spec::V1::VERSION = '0.5.0';
 # ABSTRACT: Load modules based on specifications V1
 use 5.010001;
 
 # use strict;
 # use warnings;
 
-use Safe::Isa ();
-
 our @EXPORT_OK = qw(need_module try_module);
 
 state $MODULE_RE  = qr/ [^\W\d]\w*+ (?: :: \w++ )*+ /x;
@@ -67,8 +65,6 @@ state $_OPTS = _opts();
 # need_module($spec)
 # need_module($spec, \%opts)
 sub need_module {
-    shift if $_[0]->$Safe::Isa::_isa(__PACKAGE__);    # Discard invocant
-
     my $opts = @_ > 1 ? _opts(pop) : $_OPTS;
 
     my ( $m, @v ) = _parse_module_spec( $_[-1] )
@@ -78,6 +74,36 @@ sub need_module {
     return wantarray ? ( $m, $m->VERSION ) : $m;
 }
 
+# generate_code($spec, \%opts);
+sub generate_code {
+    my $opts = @_ > 1 ? pop : {};
+    $opts->{context} ||= 'void';
+    $opts->{indent}  ||= ' ' x 4;
+
+    my ( $m, @v ) = _parse_module_spec( $_[-1] )
+      or croak(qq(Can't parse $_[-1]}));
+    my $code = "require $m;\n";
+    $code .= "$m->VERSION('$v[0]');\n" if @v;
+
+    if ( $opts->{context} eq 'void' ) {
+
+        # nothing to do
+    }
+    elsif ( $opts->{context} eq 'scalar' ) {
+        $code .= "'$m';\n";
+    }
+    elsif ( $opts->{context} eq 'list' ) {
+        $code .= "('$m', '$m'->VERSION);\n";
+    }
+
+    if ( $opts->{wrap} ) {
+        $code =~ s/^/$opts->{indent}/mg if $opts->{indent};
+        $code = "do {\n$code};\n";
+    }
+
+    return $code;
+}
+
 sub _opts {
     my %opts = ( require => 1, %{ shift // {} } );
 
@@ -96,8 +122,6 @@ sub _opts {
 # try_module($spec)
 # try_module($spec, \%opts)
 sub try_module {
-    shift if $_[0]->$Safe::Isa::_isa(__PACKAGE__);    # Discard invocant
-
     my $opts = @_ > 1 ? _opts(pop) : $_OPTS;
 
     my ( $m, @v ) = _parse_module_spec( $_[-1] )
@@ -120,10 +144,10 @@ sub try_module {
 
 # TODO need_modules($spec1, $spec1)
 
-# Borrowed from Mojo::Util
-sub _class_to_path { join '.', join( '/', split( /::|'/, shift ) ), 'pm' }
-
-sub _require_module { require(&_class_to_path) }
+sub _require_module {
+    ( my $f = "$_[0].pm" ) =~ s{::}{/}g;
+    require $f;
+}
 
 sub croak {
     require Carp;
@@ -283,7 +307,7 @@ Module::Spec::V1 - Load modules based on specifications V1
 
 =head1 VERSION
 
-version 0.4.0
+version 0.5.0
 
 =head1 SYNOPSIS
 
